@@ -1,5 +1,5 @@
 jomo1ran.MCMCchain <-
-  function(Y, X=NULL, Z=NULL,clus, beta.start=NULL, u.start=NULL, l1cov.start=NULL, l2cov.start=NULL, l1cov.prior=NULL, l2cov.prior=NULL, start.imp=NULL, nburn=100, a=NULL, meth="common", output=1, out.iter=10) {
+  function(Y, X=NULL, Z=NULL,clus, beta.start=NULL, u.start=NULL, l1cov.start=NULL, l2cov.start=NULL, l1cov.prior=NULL, l2cov.prior=NULL, start.imp=NULL, nburn=1000, a=NULL, meth="common", output=1, out.iter=10) {
     stopifnot(meth=="common"|meth=="fixed"|meth=="random")
     ncon=0
     ncat=0
@@ -33,7 +33,7 @@ jomo1ran.MCMCchain <-
     if (is.null(Z)) Z=matrix(1,nrow(Y),1)
     if (meth=="common") {
       if (ncat==0 & ncon>0) {
-        cat("Found ", ncon, "continuous outcomes and no categorical. Using function jomoran1con.", "\n")
+        cat("Found ", ncon, "continuous outcomes and no categorical. Using function jomo1rancon.", "\n")
         imp<-jomo1rancon.MCMCchain(Y=Y.con, X=X, Z=Z, clus=clus, beta.start=beta.start, u.start=u.start, l1cov.start=l1cov.start, l2cov.start=l2cov.start, l1cov.prior=l1cov.prior, l2cov.prior=l2cov.prior, start.imp=start.imp, nburn=nburn, output=output,out.iter=out.iter)
         attr(imp, "function") = "jomo1rancon.MCMCchain"
       }
@@ -50,34 +50,34 @@ jomo1ran.MCMCchain <-
     }
     if (meth=="fixed") {
       if (ncat==0 & ncon>0) {
-        cat("Found ", ncon, "continuous outcomes and no categorical. Using function jomoran1conhr with fixed cluster-l1cov.priorecific covariance matrices.", "\n")
+        cat("Found ", ncon, "continuous outcomes and no categorical. Using function jomo1ranconhr with fixed cluster-specific covariance matrices.", "\n")
         imp<-jomo1ranconhr.MCMCchain(Y=Y.con, X=X, Z=Z, clus=clus, beta.start=beta.start, u.start=u.start, l1cov.start=l1cov.start, l2cov.start=l2cov.start, l1cov.prior=l1cov.prior, l2cov.prior=l2cov.prior, start.imp=start.imp, nburn=nburn, a=0, meth="fixed", output=output,out.iter=out.iter)
         attr(imp, "function") = "jomo1ranconhr.MCMCchain.fixed"
       }
       if (ncat>0 & ncon==0) {
-        cat("Found ", ncat, "categorical outcomes and no continuous. Using function jomo1rancathr with fixed cluster-l1cov.priorecific covariance matrices.", "\n")
+        cat("Found ", ncat, "categorical outcomes and no continuous. Using function jomo1rancathr with fixed cluster-specific covariance matrices.", "\n")
         imp<-jomo1rancathr.MCMCchain(Y.cat=Y.cat,Y.numcat=Y.numcat, X=X, Z=Z, clus=clus, beta.start=beta.start, u.start=u.start, l1cov.start=l1cov.start, l2cov.start=l2cov.start, l1cov.prior=l1cov.prior, l2cov.prior=l2cov.prior, start.imp=start.imp, nburn=nburn, a=0, meth="fixed", output=output,out.iter=out.iter)
         attr(imp, "function") = "jomo1rancathr.MCMCchain.fixed"
       }
       if (ncat>0 & ncon>0) {
-        cat("Found ", ncon, "continuous outcomes and ", ncat, "categorical. Using function jomo1ranmixhr with fixed cluster-l1cov.priorecific covariance matrices.", "\n")
+        cat("Found ", ncon, "continuous outcomes and ", ncat, "categorical. Using function jomo1ranmixhr with fixed cluster-specific covariance matrices.", "\n")
         imp<-jomo1ranmixhr.MCMCchain(Y.con=Y.con,Y.cat=Y.cat,Y.numcat=Y.numcat, X=X, Z=Z, clus=clus, beta.start=beta.start, u.start=u.start, l1cov.start=l1cov.start, l2cov.start=l2cov.start, l1cov.prior=l1cov.prior, l2cov.prior=l2cov.prior, start.imp=start.imp, nburn=nburn,a=0, meth="fixed", output=output,out.iter=out.iter)
         attr(imp, "function") = "jomo1ranmixhr.MCMCchain.fixed"
       }
     }
     if (meth=="random") {
       if (ncat==0 & ncon>0) {
-        cat("Found ", ncon, "continuous outcomes and no categorical. Using function jomoran1conhr with random cluster-l1cov.priorecific covariance matrices.", "\n")
+        cat("Found ", ncon, "continuous outcomes and no categorical. Using function jomo1ranconhr with random cluster-specific covariance matrices.", "\n")
         imp<-jomo1ranconhr.MCMCchain(Y=Y.con, X=X, Z=Z, clus=clus, beta.start=beta.start, u.start=u.start, l1cov.start=l1cov.start, l2cov.start=l2cov.start, l1cov.prior=l1cov.prior, l2cov.prior=l2cov.prior, start.imp=start.imp, nburn=nburn, a=a, meth="random", output=output,out.iter=out.iter)
         attr(imp, "function") = "jomo1ranconhr.MCMCchain.random"
       }
       if (ncat>0 & ncon==0) {
-        cat("Found ", ncat, "categorical outcomes and no continuous. Using function jomo1rancathr with random cluster-l1cov.priorecific covariance matrices.", "\n")
+        cat("Found ", ncat, "categorical outcomes and no continuous. Using function jomo1rancathr with random cluster-specific covariance matrices.", "\n")
         imp<-jomo1rancathr.MCMCchain(Y.cat=Y.cat,Y.numcat=Y.numcat, X=X, Z=Z, clus=clus, beta.start=beta.start, u.start=u.start, l1cov.start=l1cov.start, l2cov.start=l2cov.start, l1cov.prior=l1cov.prior, l2cov.prior=l2cov.prior, start.imp=start.imp, nburn=nburn, a=a, meth="random", output=output,out.iter=out.iter)
         attr(imp, "function") = "jomo1rancathr.MCMCchain.random"
       }
       if (ncat>0 & ncon>0) {
-        cat("Found ", ncon, "continuous outcomes and ", ncat, "categorical. Using function jomo1ranmixhr with random cluster-l1cov.priorecific covariance matrices.", "\n")
+        cat("Found ", ncon, "continuous outcomes and ", ncat, "categorical. Using function jomo1ranmixhr with random cluster-specific covariance matrices.", "\n")
         imp<-jomo1ranmixhr.MCMCchain(Y.con=Y.con,Y.cat=Y.cat,Y.numcat=Y.numcat, X=X, Z=Z, clus=clus, beta.start=beta.start, u.start=u.start, l1cov.start=l1cov.start, l2cov.start=l2cov.start, l1cov.prior=l1cov.prior, l2cov.prior=l2cov.prior, start.imp=start.imp, nburn=nburn,a=a, meth="random", output=output,out.iter=out.iter)
         attr(imp, "function") = "jomo1ranmixhr.MCMCchain.random"
       }
