@@ -1,5 +1,5 @@
 jomo1ranmixhr <-
-function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=NULL, l1cov.start=NULL, l2cov.start=NULL, l1cov.prior=NULL, l2cov.prior=NULL, nburn=100, nbetween=100, nimp=5, a=NULL, meth="random", output=1, out.iter=10) {
+function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=NULL, l1cov.start=NULL, l2cov.start=NULL, l1cov.prior=NULL, l2cov.prior=NULL, nburn=1000, nbetween=1000, nimp=5, a=NULL, meth="random", output=1, out.iter=10) {
   if (nimp<2) {
     nimp=2
     cat("Minimum number of imputations:2. For single imputation using function jomo1ranmixhr.MCMCchain\n")
@@ -8,7 +8,7 @@ function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=
   if (is.null(Z)) Z=matrix(1,nrow(Y.cat),1)
   if (is.null(beta.start)) beta.start=matrix(0,ncol(X),(ncol(Y.con)+(sum(Y.numcat)-length(Y.numcat))))
   if (is.null(l1cov.prior)) l1cov.prior=diag(1,ncol(beta.start))
-  if (is.null(a)) a=ncol(beta.start)
+  if (is.null(a)) a=ncol(beta.start)+5.5
   clus<-factor(unlist(clus))
   previous_levels_clus<-levels(clus)
   levels(clus)<-0:(nlevels(clus)-1)
@@ -95,7 +95,7 @@ function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=
   covupost<- array(0, dim=c(nrow(l2cov.start),ncol(l2cov.start),(nimp-1)))
   cpost<-matrix(0,nrow(l2cov.start),ncol(l2cov.start))
   meanobs<-colMeans(Yi,na.rm=TRUE)
-  for (i in 1:nrow(Yi)) for (j in 1:ncol(Yi)) if (is.na(Yimp[i,j])) Yimp2[i,j]=meanobs[j]
+  for (i in 1:nrow(Yi)) for (j in 1:ncol(Yi)) if (is.na(Yimp[i,j])) Yimp2[i,j]=rnorm(1,meanobs[j],1)
   if (meth=="fixed") {
     .Call("jomo1ranmixhf", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit,cpost,nburn, l1cov.prior,l2cov.prior,Y.numcat, ncol(Y.con),ait,out.iter, PACKAGE = "jomo")
   }
