@@ -36,10 +36,10 @@ double r8_gamma_log ( double x );
 double log_mul_gamma ( int p, double a ); 
 double r8_chi_pdf ( double df, double rval ); 
 double wishart_dens ( double df, int dim, double X[], double invA[], double help[], double help2[]); 
-double log_f_u ( double eta, double a, int dim, int nclus, double allinvomega[], double omega[], double invA[], double help[], double help2[]);
-double derive_log_f_u ( double dx, double eta, double u, int dim, int nclus, double allomega[], double omega[], double invA[], double help[], double help2[]);
-double derive2_log_f_u ( double dx, double eta, double u, int dim, int nclus, double allomega[], double omega[], double invA[], double help[], double help2[]);
-double derive2_f_u ( double dx, double eta, double u, int dim, int nclus, double allomega[], double omega[], double invA[], double help[], double help2[], double K);
-double newton_raphson ( double x, double precision, double dx, double eta, int dim, int nclus, double allomega[], double omega[], double invA[], double help[], double help2[]); 
+double log_f_u ( double eta, double u, int dim, int nclus, double allinvomega[], double omega[], double invgamma[], double help[], double help2[]);
+double derive_log_f_u ( double dx, double eta, double u, int dim, int nclus, double allinvomega[], double omega[], double invgamma[], double help[], double help2[]);
+double derive2_log_f_u ( double dx, double eta, double u, int dim, int nclus, double allinvomega[], double omega[], double invgamma[], double help[], double help2[]);
+double derive2_f_u ( double dx, double eta, double u, int dim, int nclus, double allinvomega[], double omega[], double invgamma[], double help[], double help2[], double K);
+double newton_raphson ( double x, double precision, double dx, double eta, int dim, int nclus, double allinvomega[], double omega[], double invgamma[], double help[], double help2[]); 
 double h_u ( double u, double u_m, double lambda ); 
 double t_sample ( double df , int fl);
